==> nextcloud-18.0.2.tgz: nextcloud/apps/twofactor_backupcodes/l10n/hr.js <==
OC.L10N.register(
    "twofactor_backupcodes",
    {
    "_" : "_",
    "An error occurred while generating your backup codes" : "Došlo je do pogreške pri generiranju pričuvnih šifri",
    "{name} backup codes" : "{name} pričuvnih šifri",
    "These are your backup codes. Please save and/or print them as you will not be able to read the codes again later" : "Ovo su vaše pričuvne šifre. Spremite ih i/ili ih ispišite jer ih kasnije više nećete moći pročitati",
    "Save backup codes" : "Spremi pričuvne šifre",
    "Print backup codes" : "Ispis pričuvnih šifri",
    "Backup codes have been generated. {used} of {total} codes have been used." : "Pričuvne šifre su generirane. Iskorišteno je {used} od {total} šifri.",
    "Regenerate backup codes" : "Ponovno generiranje pričuvnih šifri",
    "_icon-loading-small_::_generate-backup-codes_" : ["icon-loading-small","generate-backup-codes","generate-backup-codes"],
    "If you regenerate backup codes, you automatically invalidate old codes." : "Ako ponovno generirate pričuvne šifre, automatski poništavate stare šifre.",
    "Generate backup codes" : "Generiraj pričuvne šifre",
    "You created two-factor backup codes for your account" : "Stvorili ste dvofaktorske pričuvne šifre za svoj račun",
    "Second-factor backup codes" : "Pričuvne šifre drugog faktora",
    "You enabled two-factor authentication but did not generate backup codes yet. They are needed to restore access to your account in case you lose your second factor." : "Omogućili ste dvofaktorsku autentifikaciju, ali još niste generirali pričuvne šifre. One su potrebne kako bi vratili pristup svom računu u slučaju da izgubite svoj drugi faktor.",
    "Backup code" : "Pričuvna šifra",
    "Use backup code" : "Upotrijebi pričuvnu šifru",
    "Two factor backup codes" : "Dvofaktorske pričuvne šifre",
    "A two-factor auth backup codes provider" : "Davatelj pričuvnih šifri za dvofaktorsku autentifikaciju",
    "Use one of the backup codes you saved when setting up two-factor authentication." : "Upotrijebite jednu od pričuvnih šifri koje ste spremili prilikom postavljanja dvofaktorske autentifikacije.",
    "Submit" : "Šalji",
    "You have enabled two-factor authentication but have not yet generated backup codes. Be sure to do this in case you lose access to your second factor." : "Omogućili ste dvofaktorsku autentifikaciju, ali još niste generirali pričuvne šifre. Obavezno to učinite u slučaju da izgubite pristup svom drugom faktoru.",
    "function" : "funkcija"
},
"nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");

==> nextcloud-19.0.4.tgz: nextcloud/apps/twofactor_backupcodes/l10n/hr.js <==
OC.L10N.register(
    "twofactor_backupcodes",
    {
    "You created two-factor backup codes for your account" : "Stvorili ste dvofaktorske pričuvne šifre za svoj račun",
    "Second-factor backup codes" : "Pričuvne šifre drugog faktora",
    "Generate backup codes" : "Generiraj pričuvne šifre",
    "You enabled two-factor authentication but did not generate backup codes yet. They are needed to restore access to your account in case you lose your second factor." : "Omogućili ste dvofaktorsku autentifikaciju, ali još niste generirali pričuvne šifre. One su potrebne kako bi vratili pristup svom računu u slučaju da izgubite svoj drugi faktor.",
    "Backup code" : "Pričuvna šifra",
    "Use backup code" : "Upotrijebi pričuvnu šifru",
    "Two factor backup codes" : "Dvofaktorske pričuvne šifre",
    "A two-factor auth backup codes provider" : "Davatelj pričuvnih šifri za dvofaktorsku autentifikaciju",
    "Backup codes have been generated. {used} of {total} codes have been used." : "Pričuvne šifre su generirane. Iskorišteno je {used} od {total} šifri.",
    "These are your backup codes. Please save and/or print them as you will not be able to read the codes again later" : "Ovo su vaše pričuvne šifre. Spremite ih i/ili ih ispišite jer ih kasnije više nećete moći pročitati",
    "Save backup codes" : "Spremi pričuvne šifre",
    "Print backup codes" : "Ispis pričuvnih šifri",
    "Regenerate backup codes" : "Ponovno generiranje pričuvnih šifri",
    "If you regenerate backup codes, you automatically invalidate old codes." : "Ako ponovno generirate pričuvne šifre, automatski poništavate stare šifre.",
    "An error occurred while generating your backup codes" : "Došlo je do pogreške pri generiranju pričuvnih šifri",
    "{name} backup codes" : "{name} pričuvnih šifri",
    "Use one of the backup codes you saved when setting up two-factor authentication." : "Upotrijebite jednu od pričuvnih šifri koje ste spremili prilikom postavljanja dvofaktorske autentifikacije.",
    "Submit" : "Šalji",
    "function" : "funkcija",
    "_" : "_",
    "_icon-loading-small_::_generate-backup-codes_" : ["icon-loading-small","generate-backup-codes","generate-backup-codes"]
},
"nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");
